function [t,x]=expl_euler(f,t0,x0,h,N)
% N Schritte expliziter Euler mit konstante Schrittweite h fuer x'=f(t,x)
% Input:
%    f          rechte Seite; eine Funktion der Form
%                   dx = f(t,x)
%    t0         Startzeitpunkt
%    x0         Startzustand
%    h          konstante Schrittweite
%    N          Anzahl der Schritte
% Ausgabe:   komplette Trajektorie: (t,x)
%    t          Zeilenvektor der Laenge N+1 mit Zeitpunkten
%    x          (length(x0),N+1) Matrix mit den Zustaenden in den Spalten

N=round(N);                          % sicherheitshalber
x=NaN*ones(length(x0),N+1);          % Speicher fuer Zustaende
t=NaN*ones(1,N+1);                   % Speicher fuer Zeitpunkte
t(:,1)=t0; x(:,1)=x0;                % Anfangswert
for k=1:N                            % N Schritte machen
    feval=f(t(k),x(:,k));            % f auswerten
    x(:,k+1)=x(:,k)+h*feval;         % Update Zustand
    t(k+1)=t(k)+h;                   % Update Zeit
end
end