function [t,x]=impl_euler(f,t0,x0,h,N)
% N Schritte impliziter Euler mit konstanter Schrittweite h fuer x'=f(t,x)
% Input:
%    f          rechte Seite; eine Funktion der Form
%                   dx = f(t,x)
%    t0         Startzeitpunkt
%    x0         Startzustand
%    h          konstante Schrittweite
%    N          Anzahl der Schritte
% Ausgabe:   komplette Trajektorie: (t,x)
%    t          Zeilenvektor der Laenge N+1 mit Zeitpunkten
%    x          (length(x0),N+1) Matrix mit den Zustaenden in den Spalten
options = optimset('Display','off');
N=round(N);                          % sicherheitshalber
x=NaN*ones(length(x0),N+1);          % Speicher fuer Zustaende
t=NaN*ones(1,N+1);                   % Speicher fuer Zeitpunkte
t(:,1)=t0; x(:,1)=x0;                % Anfangswert
for k=1:N                            % N Schritte machen
    t(k+1)=t(k)+h;                   % Update Zeit
    x(:,k+1) = fsolve(@(xx)(xx-x(:,k)-h*f(t(k+1),xx)),x(:,k),options);
end
end