function [A,b]=laplExample (n)
% Laplace-Gleichung auf dem Einheitsquadrat [0,1]^2 mit 
% Fnf-Punkte-Stern diskretisieren und fr die rechte Seite
% f = 2*pi^2*sin(pi*x)*sin(pi*y)
% lsen.
% Hinweis: f ist so gewhlt, dass
% u(x,y)= sin(pi*x)*sin(pi*y)
% die exakte Lsung ist.
%
% Input
%       n      n^2 ist die Anzahl der INNEREN Punkte (Freiheitsgrade)

if nargin<1, n=2^6-1;end

f = @(x,y) 2.*pi^2.*sin(pi*x).*sin(pi*y);

%% exakte Lsung als Funktion (zum Vergleich)

uExakt = @(x,y) sin(pi*x).*sin(pi*y);

%% Matrix aufstellen
mo=-ones(n,1);I=speye(n);                          % Hilfsgren

D=spdiags([ 4*ones(n,1), mo, mo ],[0,-1,1],n,n);   % A_n Block
C=spdiags([ mo,mo ],[-1,1],n,n);                   % Position der Nebend.
A=(kron(I,D)+kron(C,I))*((n+1).^2);                % Kronecker

%% rechte Seite auftellen
[X,Y]=meshgrid((1:n)./(n+1));                      % innere Punkte
b=f(X,Y);b=b(:);

%% sparse LGS lsen
u=A\b;

%% Visualisierung: nherungslsung
[X,Y]=meshgrid(linspace(0,1,n+2));                 % Mesh MIT Rand
Z=zeros(size(X));
Z(2:end-1,2:end-1)=reshape(u,n,n);                % u im Inneren
figure(1);
surf(X,Y,Z);
title(['n=',num2str(n)]);
%% Fehler
uRight=uExakt(X,Y);

fprintf('maximale Abweichung von exakter Lsung: %1.15e\n',...
    max(max(abs(Z-uRight))));

%% Visualisierung: exakte Lsung
[Xe,Ye]=meshgrid(linspace(0,1,1e3));
Ze=uExakt(Xe,Ye);
figure(2);
surf(Xe,Ye,Ze,'EdgeColor','none','FaceColor',0.8*ones(1,3));
camlight;
title('exakte Lsung')

end

